# macros for sysvinit transition - should be equal to
# sysvinit %version-%release-plus-1
%define sysvinit_version 2.87
%define subrel 4
%define sysvinit_release %mkrel 13

# (eugeni) for backports and old distributions, rely on EVRD as well
%if %mdkversion < 201100
%define EVRD %{?epoch:%{epoch}:}%{?version:%{version}}%{?release:-%{release}}%{?distepoch::%{distepoch}}
%endif


Summary:	A System and Session Manager
Name:		systemd
Version:	29
Release:	%mkrel 8
License:	GPLv2+
Group:		System/Configuration/Boot and Init
Url:		http://www.freedesktop.org/wiki/Software/systemd
Source0:	http://www.freedesktop.org/software/systemd/%{name}-%{version}.tar.bz2

# (bor) clean up directories on boot as done by rc.sysinit
Patch16:	systemd-18-clean-dirs-on-boot.patch
# (bor) reset /etc/mtab on boot (why is it not a link)?
Patch17:	systemd-18-reset-mtab-on-boot.patch
# (bor) allow explicit stdout configuration for SysV scripts
#Patch18:	systemd-19-sysv_std_output.patch
# (bor) fix potential deadlock when onseshot unit is not finished
Patch19:	systemd-19-apply-timeoutsec-to-oneshot-too.patch
# (bor) network filesystems do not need quota service (mdv#62746)
#Patch21:	systemd-19-no-quotacheck-for-netfs.patch
Patch22: systemd-tmpfilesd-utmp-temp-patch.patch
Patch23: systemd-29.hwclock.patch
Patch24: systemd-halt-pre.patch
Patch25: systemd-29-rc-local.patch
Patch26:	systemd-29-CVE-2012-1174.diff
Patch27:	0001-execute-don-t-choke-when-systemd-was-compiled-with-a.patch
BuildRequires:	cryptsetup-devel
BuildRequires:	dbus-devel >= 1.4.0
BuildRequires:	libudev-devel >= 160
BuildRequires:	libcap-devel
BuildRequires:	tcp_wrappers-devel
BuildRequires:	pam-devel
BuildRequires:	dbus-glib-devel
BuildRequires:	vala >= 0.9
BuildRequires:	gtk2-devel glib2-devel libnotify-devel
BuildRequires:  libxslt-devel
BuildRequires:  docbook-style-xsl
# TODO for P12, remove when it is removed
BuildRequires:	automake autoconf
Requires:	systemd-units = %{EVRD}
Requires:	dbus >= 1.3.2
Requires:	udev >= 160
Requires:	initscripts >= 9.21-3mdv2011.0
Requires:	util-linux-ng >= 2.18-2mdv2011.0
Conflicts:	initscripts < 9.24
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
systemd is a system and session manager for Linux, compatible with
SysV and LSB init scripts. systemd provides aggressive parallelization
capabilities, uses socket and D-Bus activation for starting services,
offers on-demand starting of daemons, keeps track of processes using
Linux cgroups, supports snapshotting and restoring of the system
state, maintains mount and automount points and implements an
elaborate transactional dependency-based service control logic. It can
work as a drop-in replacement for sysvinit.

%package units
Summary:	Configuration files, directories and installation tool for systemd
Group:		System/Configuration/Boot and Init

%description units
Basic configuration files, directories and installation tool for the systemd
system and session manager.

%package gtk
Summary:        Graphical frontend for systemd
Group:          System/Configuration/Boot and Init
Requires:       %{name} = %{version}-%{release}

%description gtk
Graphical front-end for systemd.

%package sysvinit
Summary:        System V init tools
Group:          System/Configuration/Boot and Init
Requires:       %{name} = %{version}-%{release}
# (eugeni) systemd should work as a drop-in replacement for sysvinit, but not obsolete it
Provides:       sysvinit = %sysvinit_version-%sysvinit_release, SysVinit = %sysvinit_release-%sysvinit_release
Conflicts:      sysvinit < %sysvinit_version-%sysvinit_release, SysVinit < %sysvinit_release-%sysvinit_release

%description sysvinit
Drop-in replacement for the System V init tools of systemd.

%prep
%setup -q
%apply_patches

find src/ -name "*.vala" -exec touch '{}' \;

%build
# TODO for P12, remove when it is removed
autoreconf -fis
%configure2_5x \
	--with-rootdir=

%make

%install
rm -rf %{buildroot}

%makeinstall_std
find %{buildroot} \( -name '*.a' -o -name '*.la' \) -exec rm {} \;

# (bor) create late shutdown directory
mkdir -p %{buildroot}/lib/systemd/system-shutdown

# Create SysV compatibility symlinks. systemctl/systemd are smart
# enough to detect in which way they are called.
mkdir -p %{buildroot}/sbin
ln -s ../bin/systemd %{buildroot}/sbin/init
ln -s ../bin/systemctl %{buildroot}/sbin/reboot
ln -s ../bin/systemctl %{buildroot}/sbin/halt
ln -s ../bin/systemctl %{buildroot}/sbin/poweroff
ln -s ../bin/systemctl %{buildroot}/sbin/shutdown
ln -s ../bin/systemctl %{buildroot}/sbin/telinit
ln -s ../bin/systemctl %{buildroot}/sbin/runlevel

# We create all wants links manually at installation time to make sure
# they are not owned and hence overriden by rpm after the used deleted
# them.
rm -r %{buildroot}%{_sysconfdir}/systemd/system/*.target.wants
rm -f %{buildroot}%{_sysconfdir}/systemd/system/display-manager.service

# And the default symlink we generate automatically based on inittab
rm -f %{buildroot}%{_sysconfdir}/systemd/system/default.target

# We are not prepared to deal with tmpfs /var/run or /var/lock
pushd %{buildroot}/lib/systemd/system/local-fs.target.wants && {
        rm -f var-lock.mount
        rm -f var-run.mount
popd
}

# (bor) make sure we own directory for bluez to install service
mkdir -p %{buildroot}/lib/systemd/system/bluetooth.target.wants

# use consistent naming and permissions for completion scriplets
mv %{buildroot}%{_sysconfdir}/bash_completion.d/systemctl-bash-completion.sh \
    %{buildroot}%{_sysconfdir}/bash_completion.d/systemctl
chmod 644 %{buildroot}%{_sysconfdir}/bash_completion.d/systemctl

# (bor) disable legacy output to console, it just messes things up
sed -i -e 's/^#SysVConsole=yes$/SysVConsole=no/' \
	%{buildroot}/etc/systemd/system.conf

# (bor) enable rpcbind.target by default so we have something to plug
#	portmapper service into
ln -s ../rpcbind.target %{buildroot}/lib/systemd/system/multi-user.target.wants

# (bor) machine-id-setup is in /sbin in post-v20
install -d %{buildroot}/sbin && \
	mv %{buildroot}/bin/systemd-machine-id-setup %{buildroot}/sbin

# (eugeni) install /run
mkdir %{buildroot}/run

# add missing ttys (mdv #63600)
mkdir -p %{buildroot}/etc/systemd/system/getty.target.wants
pushd %{buildroot}/etc/systemd/system/getty.target.wants
	for _term in 1 2 3 4 5 6 ; do
	ln -s /lib/systemd/system/getty@.service getty@tty$_term.service
	done
popd
# add /etc/hostname
touch %{buildroot}%{_sysconfdir}/hostname
# create modules.conf as a symlink to /etc/
ln -s /etc/modules %{buildroot}%{_sysconfdir}/modules-load.d/modules.conf

%clean
rm -rf %{buildroot}

%triggerin -- glibc
# reexec daemon on self or glibc update to avoid busy / on shutdown
# trigger is executed on both self and target install so no need to have
# extra own post
if [ $1 -ge 2 -o $2 -ge 2 ] ; then
	/bin/systemctl daemon-reexec 2>&1 || :
fi

%post
/sbin/systemd-machine-id-setup

%triggerin units -- %{name}-units < 19-4
# Enable the services we install by default.
/bin/systemctl --quiet enable \
	hwclock-load.service \
	quotaon.service \
	quotacheck.service \
	systemd-readahead-replay.service \
	systemd-readahead-collect.service \
	2>&1 || :
# rc-local is now enabled by default in base package
rm -f /etc/systemd/system/multi-user.target.wants/rc-local.service || :

%post units
if [ $1 -eq 1 ] ; then
        # Try to read default runlevel from the old inittab if it exists
        runlevel=$(/bin/awk -F ':' '$3 == "initdefault" && $1 !~ "^#" { print $2 }' /etc/inittab 2> /dev/null)
        if [ -z "$runlevel" ] ; then
                target="/lib/systemd/system/graphical.target"
        else
                target="/lib/systemd/system/runlevel$runlevel.target"
        fi

        # And symlink what we found to the new-style default.target
        /bin/ln -sf "$target" %{_sysconfdir}/systemd/system/default.target 2>&1 || :

	# Enable the services we install by default.
	/bin/systemctl --quiet enable \
		hwclock-load.service \
		getty@.service \
		quotaon.service \
		quotacheck.service \
		remote-fs.target \
		systemd-readahead-replay.service \
		systemd-readahead-collect.service \
		2>&1 || :
fi

%preun units
if [ $1 -eq 0 ] ; then
        /bin/systemctl --quiet disable \
		hwclock-load.service \
		getty@.service \
		quotaon.service \
		quotacheck.service \
		remote-fs.target \
		systemd-readahead-replay.service \
		systemd-readahead-collect.service \
		2>&1 || :

        /bin/rm -f /etc/systemd/system/default.target 2>&1 || :
fi

%postun units
if [ $1 -ge 1 ] ; then
        /bin/systemctl daemon-reload 2>&1 || :
fi

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.systemd1.conf
%config(noreplace) %{_sysconfdir}/systemd/system.conf
%config(noreplace) %{_sysconfdir}/hostname
%dir %{_sysconfdir}/tmpfiles.d
%dir %{_sysconfdir}/modules-load.d/modules.conf
%{_sysconfdir}/xdg/systemd
/bin/systemd
/bin/systemd-ask-password
/bin/systemd-notify
/bin/systemd-tmpfiles
/bin/systemd-tty-ask-password-agent
/sbin/systemd-machine-id-setup
%dir /lib/systemd
%dir /lib/systemd/system-generators
%dir /lib/systemd/system-shutdown
/lib/systemd/systemd-*
/lib/systemd/system-generators/*
/lib/udev/rules.d/*.rules
%dir /usr/lib/tmpfiles.d/
%dir /usr/lib/modules-load.d
/usr/lib/tmpfiles.d/legacy.conf
/usr/lib/tmpfiles.d/systemd.conf
/usr/lib/tmpfiles.d/x11.conf
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.hostname1.conf
/%{_lib}/security/pam_systemd.so
%{_bindir}/systemd-analyze
%{_bindir}/systemd-cgls
%{_bindir}/systemd-nspawn
%{_bindir}/systemd-stdio-bridge
%{_mandir}/man1/systemd.*
%{_mandir}/man1/systemd-ask-password.*
%{_mandir}/man1/systemd-notify.*
%{_mandir}/man1/systemd-nspawn.*
%{_mandir}/man1/systemd-cgls.*
%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man7/*
%{_mandir}/man8/pam_systemd.*
%{_mandir}/man8/systemd-tmpfiles.*
%{_datadir}/dbus-1/system-services/org.freedesktop.hostname1.service
%{_datadir}/dbus-1/services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.*.xml
%{_datadir}/polkit-1/actions/org.freedesktop.systemd1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.hostname1.policy
%{_docdir}/systemd

%files units
%defattr(-,root,root)
/bin/systemctl
%dir %{_sysconfdir}/systemd
%dir %{_sysconfdir}/systemd/system
%dir %{_sysconfdir}/systemd/user
%{_sysconfdir}/systemd/system/getty.target.wants/getty@*.service
%dir %{_sysconfdir}/systemd/system/getty.target.wants
%{_sysconfdir}/bash_completion.d/systemctl
/lib/systemd/system
/usr/lib/systemd/
%{_mandir}/man1/systemctl.*
%{_datadir}/pkgconfig/systemd.pc

%files gtk
%defattr(-,root,root)
%{_bindir}/systemadm
%{_bindir}/systemd-gnome-ask-password-agent
%{_mandir}/man1/systemadm.*

%files sysvinit
%defattr(-,root,root,-)
/sbin/init
/sbin/reboot
/sbin/halt
/sbin/poweroff
/sbin/shutdown
/sbin/telinit
/sbin/runlevel
%{_mandir}/man1/init.*
%{_mandir}/man8/halt.*
%{_mandir}/man8/reboot.*
%{_mandir}/man8/shutdown.*
%{_mandir}/man8/poweroff.*
%{_mandir}/man8/telinit.*
%{_mandir}/man8/runlevel.*
%dir /run




%changelog
* Mon Mar 26 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 29-8.4mdv2011.0
+ Revision: 787061
- don't choke when systemd was compiled with a different CAP_LAST_CAP then what
  it is run with (#65398)
- reapply fix for CVE-2012-1174
- fix duplicates in %%files

* Sun Mar 18 2012 Security Team <security@mandriva.com> 29-8.3
+ Revision: 785468
- fix #65398 by dropping the fix for CVE-2012-1174 as this don't
  apply to this version

* Fri Mar 16 2012 Security Team <security@mandriva.com> 29-8.2
+ Revision: 785370
- P26: security fix for CVE-2012-1174

* Thu Oct 20 2011 Security Team <security@mandriva.com> 29-8.1
+ Revision: 705468
- built for updates

  + Александр Казанцев <kazancas@mandriva.org>
    - fix rc-local.service start crash

  + Alexander Barakin <abarakin@mandriva.org>
    - work with /sbin/halt.pre (see #63716)
    - work with /sbin/halt.pre (see #63716)

  + Alex Burmashev <burmashev@mandriva.org>
    - added /etc/hostnamed, created symlink for /etc/modules
    - returned hwclock-load/save services
    - release up
    - tmpfilesd patch

  + Eugeni Dodonov <eugeni@mandriva.com>
    - Bump release
    - Fix non-startable ttys (#63600)

* Mon Jun 20 2011 Eugeni Dodonov <eugeni@mandriva.com> 29-1
+ Revision: 686088
- New version 29

* Wed Jun 01 2011 Wiliam Alves de Souza <wiliam@mandriva.com> 28-1
+ Revision: 682241
- Update to 28.

* Wed May 25 2011 Eugeni Dodonov <eugeni@mandriva.com> 27-1
+ Revision: 679062
- Update to 27.

* Fri Apr 08 2011 Eugeni Dodonov <eugeni@mandriva.com> 24-2
+ Revision: 651929
- Provide /run/ directory.

* Thu Apr 07 2011 Eugeni Dodonov <eugeni@mandriva.com> 24-1
+ Revision: 651785
- New version 24.

* Thu Apr 07 2011 Funda Wang <fwang@mandriva.org> 20-3
+ Revision: 651442
- rebuild for new libnotify

* Sun Mar 13 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 20-2
+ Revision: 644344
- drop Requires: systemd from systemd-units

* Fri Mar 11 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 20-1
+ Revision: 643763
- new version
- drop P5,6,7,13,15 - Mandriva support is upstream now
- implicitly build for distro=mandriva now
- drop P20 - upstream
- P22: fix D-Bus assertion due to missing dbus_error_init (GIT)
- run systemd-machine-id-setup on update
  (cf. http://lists.freedesktop.org/archives/dbus/2011-March/014187.html)

* Thu Mar 10 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 19-4
+ Revision: 643254
- P21: do not add dependency between quotacheck and network file system;
  it creates a loop and systemd removes vital services to break it (mdv#62746)
- P14: clarify unit description
- P14: resurrect and actually enable hwclock-load.service;
  it was skipped unintentionally
- enable rpcbind.target by default

* Thu Mar 03 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 19-3
+ Revision: 641448
- P20: replace with real fix from upstream (we skipped all files on
  reiserfs because it returns DT_UNKNOWN for every file) (GIT)

* Wed Mar 02 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 19-2
+ Revision: 641235
- P20: add unit to mark system boot in wtmp

* Tue Mar 01 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 19-1
+ Revision: 641120
- new version
- P18: allow explicit SysV scripts output configuration (not yet enabled)
- P19: fix timeout never applied to oneshot services
- enable native quota and readahead units

* Sun Feb 27 2011 Funda Wang <fwang@mandriva.org> 18-5
+ Revision: 640283
- rebuild to obsolete old packages

* Sat Feb 19 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 18-4
+ Revision: 638708
- make single.service alias for rescue.service to hide initscript version

* Sat Feb 19 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 18-3
+ Revision: 638684
- enable most default units now when initscripts do not do it anymore
- P15: prefdm service was dropped from upstream initscripts, do it here
- P16: empty (not just create) X11 directories on boot as done by
  rc.sysinit
- P17: reset /etc/mtab after / is remounted. We really need to make it
  symlink
- own /lib/systemd/system-{generators,shutdown}/

* Thu Feb 17 2011 Eugeni Dodonov <eugeni@mandriva.com> 18-1
+ Revision: 638086
- Update to v18.
  Drop P15 (upstream)

* Fri Feb 11 2011 Eugeni Dodonov <eugeni@mandriva.com> 17-5
+ Revision: 637316
- Drop P14, no longer needed.

  + Andrey Borzenkov <arvidjaar@mandriva.org>
    - drop P4 - we have real dbus unit now
    - P15: allow user tasks to enter real time with RT cgroups (GIT)
    - BR stuff to re-build man pages again for P15 ...

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - use consistent naming and permissions for completion scriplets

* Sun Jan 30 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 17-4
+ Revision: 634092
- own systemwide bluetooth.target.wants directory

* Sun Jan 30 2011 Eugeni Dodonov <eugeni@mandriva.com> 17-3
+ Revision: 634020
- Patch14: do not mess with system time

* Thu Jan 27 2011 Eugeni Dodonov <eugeni@mandriva.com> 17-2
+ Revision: 633186
- Rebuild to provide systemd-sysvinit matching sysvinit.

* Sun Jan 23 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 17-1
+ Revision: 632439
- new release
- drop P12 - upstream. It was already disabled

* Tue Jan 18 2011 Eugeni Dodonov <eugeni@mandriva.com> 16-2
+ Revision: 631507
- Rely on EVRD for version dependencies.

* Mon Jan 17 2011 Wiliam Alves de Souza <wiliam@mandriva.com> 16-1
+ Revision: 631315
- updated tar.bz2 to version 16
- updated to version 16

* Tue Dec 28 2010 Eugeni Dodonov <eugeni@mandriva.com> 15-4mdv2011.0
+ Revision: 625680
- Allow systemd to be installed instead of sysvinit.

* Fri Dec 03 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 15-3mdv2011.0
+ Revision: 606522
- use native shutdown services

* Fri Dec 03 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 15-2mdv2011.0
+ Revision: 605806
- P13: use /etc/mandriva-release for welcome message
- correctly disable systemd-random-seed-load.service for now
- restore systemd-update-utmp-runlevel.service

* Wed Dec 01 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 15-1mdv2011.0
+ Revision: 604583
- update to v15
- drop P2, P8: units provided by initscripts now
- rediff P4, P5
- drop P9, P10, P11: upstream
- P12: support build with libnotify < 0.7 (GIT); BR automake/autoconf
- /etc/init.d/reboot provided by initscripts now
- session* became user* now
- systemd-ask-password-agent => systemd-gnome-ask-password-agent
- for now remove most of native services from default activation
- drop docbook/xslt BR
- require recent enough initscripts

* Tue Nov 30 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-7mdv2011.0
+ Revision: 603786
- for now remove services installed or provided by initscripts package

* Sun Nov 28 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-6mdv2011.0
+ Revision: 602332
- require initscripts >= 9.21
- drop P0, use /sys/fs/cgroup (needs kernel 2.6.36)
- drop P3, S1; use /etc/init.d/halt from initscripts now
- patch1: drop, not needed with new docbook-style-xsl

* Sat Nov 06 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-5mdv2011.0
+ Revision: 593996
- patch6: do not disable reading of /etc/locale.conf

* Tue Nov 02 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-4mdv2011.0
+ Revision: 592331
- patch11: fix device ACLs after systemd installation
- patch10: fix startup with IPv6 disabled

* Mon Oct 25 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-3mdv2011.0
+ Revision: 589354
- yet another attempt to get update scripts right
- patch9: fix systemctl enable getty@.service (upstream)

* Sat Oct 16 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-2mdv2011.0
+ Revision: 586020
- patch8: fix entering single user mode, revert to /bin/sh

* Sat Oct 16 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-1mdv2011.0
+ Revision: 585969
- source1: remove some actions now performed by systemd units
- disable MountAuto and SwapAuto (Fedora)
- re-exec daemon on glibc and self update
- disable more services from rc.sysinit
- patch7: break loop between network.target and network-up.sevice
- for now disable services performed by initscripts
- getty.target is now enabled by default
- patch6: Mandriva support in locale setup
- patch5: Mandriva support in keyboard setup
- move /etc/systemd/system.conf, /bin/systemctl in main package; they are
  usable without units. Remove duplicated LICENSE inclusion.
- new version

* Sat Sep 18 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-7mdv2011.0
+ Revision: 579679
- patch4: use messagebus for special D-Bus service for now
- source1, patch3: local version of halt script that does not unmount cgroup
- do not enable prefdm.service, we start display manager in initscirpt
- fix syslog-service
- /etc/systemd and /lib/systemd should be owned by main package

* Sat Sep 18 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-6mdv2011.0
+ Revision: 579486
- fix postinstallation script to create default links

* Thu Sep 16 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-5mdv2011.0
+ Revision: 579036
- patch2: fix shutdown/reboot with legacy /sbin/halt

* Wed Sep 15 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-4mdv2011.0
+ Revision: 578750
- do not delete *.wanted files; getty does not start without them
- set distro to fedora for now; too much is missing with 'other'

* Wed Sep 15 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-3mdv2011.0
+ Revision: 578704
- it's _initrddir, not _initdir

* Wed Sep 15 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-2mdv2011.0
+ Revision: 578688
- patch1: fix man pages rebuild after patch0
- patch0: use /cgroup until /sys/fs/cgroup is supported by kernel
- runlevelN.target are in /lib now
- remove Requires: libudev, it is computed automatically

* Wed Sep 15 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 10-1mdv2011.0
+ Revision: 578379
- prepare to release as dbus was updated to 1.4.0 version
- fix file list
- import systemd

  + Andrey Borzenkov <arvidjaar@mandriva.org>
    - new version

